Function rustc_trans::middle::ty::positional_element_tyUnstable
[-] [+]
[src]
pub fn positional_element_ty(cx: &ctxt<'tcx>, ty: &'tcx TyS<'tcx>, i: usize, variant: Option<DefId>) -> Option<&'tcx TyS<'tcx>>
Returns the type of element at index i in tuple or tuple-like type t.
For an enum t, variant is None only if t is a univariant enum.